@@ -11,6 +11,8 @@ from repoze.what import predicates
 from tw.api import WidgetsList
 import tw.forms as twf
 
+from sqlalchemy.exc import OperationalError
+
 class StrollerPluginController(TGController):
     @expose('stroller.templates.index')
     def index(self, *args, **kw):
@@ -28,28 +30,42 @@ class StrollerPluginController(TGController):
         if not config.get('stroller_enabled', False):
             return abort(404, "eCommerce support not available")
 
-        self.setup_stroller_db_on_first_request()
-
-    def setup_stroller_db_on_first_request(self):
-        from stroller.model.commerce import Product
-        if not Product.__table__.exists(bind=acr.model.DBSession.bind):
-            from stroller.model import setup_stroller_database
-            from stroller.model import init_stroller_model
-
-            init_stroller_model(acr.model.DBSession, acr.model.DeclarativeBase,
-                                acr.model.User, acr.model.Group)
-            acr.model.metadata.create_all(bind=acr.model.DBSession.bind)
-            setup_stroller_database(acr.model.DBSession, acr.model.DeclarativeBase,
-                                    acr.model.User, acr.model.Group)
-
 class StrollerPlugin(AcrPlugin):
     uri = 'shop'
+    last_version = 3
 
     @property
     def controller(self):
         config['stroller_root'] = self.plugin_url()
         return StrollerPluginController()
 
+    def upgrade(self, DBSession, current_version):
+        if current_version < 1:
+            from stroller.model.commerce import Product, Category
+            from stroller.model import init_stroller_model
+
+            init_stroller_model(DBSession, acr.model.DeclarativeBase,
+                                acr.model.User, acr.model.Group)
+
+            if not Product.__table__.exists(bind=DBSession.bind):
+                acr.model.metadata.create_all(bind=DBSession.bind)
+
+            main_category = DBSession.query(Category).filter_by(name='Shop').first()
+            if not main_category:
+                from stroller.model import setup_stroller_database
+                setup_stroller_database(DBSession, acr.model.DeclarativeBase,
+                                        acr.model.User, acr.model.Group)
+
+        elif current_version < 2:
+            from stroller.model.commerce import ProductPhoto
+            if not DBSession.bind.has_table(ProductPhoto.__tablename__):
+                DBSession.bind.create(ProductPhoto.__table__)
+        elif current_version < 3:
+            try:
+                DBSession.bind.execute('ALTER TABLE stroller_order ADD confirmed SMALLINT;')
+            except OperationalError:
+                pass
+
     def init_helpers(self):
         import stroller.helpers
         acr.lib.helpers.stroller_url = stroller.helpers.stroller_url
@@ -61,10 +77,6 @@ class StrollerPlugin(AcrPlugin):
         Product, ProductInfo, Category, Order, OrderItem = init_stroller_model(acr.model.DBSession, acr.model.DeclarativeBase,
                                                                                acr.model.User, acr.model.Group)
 
-    def setup_models(self, DBSession, DeclarativeBase, User, Group):
-        from stroller.model import setup_stroller_database
-        setup_stroller_database(DBSession, DeclarativeBase, User, Group)
-
     def __init__(self):
         try:
             import stroller
