@@ -30,8 +30,14 @@ class BaseController(TGController):
 
         request.identity = request.environ.get('repoze.who.identity')
         tmpl_context.identity = request.identity
+
+        #Work-Around for IE9 passing only specific mime type for Accept Header
+        #causing crash in TG2.0
+        accept_header = request.headers.get('Accept')
+        if accept_header and '*/*' not in accept_header:
+            request.headers['Accept'] += ',*/*;q=0.1'
+            
         jquery_js.inject()
-        
         full_acr_js.inject()
         acr_css.inject()
         return TGController.__call__(self, environ, start_response)
