@@ -3,6 +3,7 @@
 from zope.interface import implements
 from repoze.who.interfaces import IAuthenticator, IMetadataProvider
 from sqlalchemy.orm.exc import NoResultFound, MultipleResultsFound
+import sqlalchemy.pool
 
 from sqlalchemy import engine_from_config
 from tg import config, request
@@ -62,6 +63,8 @@ class AcrMultiSiteEngine(object):
             raise Exception('Outside of a request and no script forced')
 
         if not self.engines.has_key(used_db):
+            if 'acrmultisite.poolclass' in config:
+                config['sqlalchemy.poolclass'] = getattr(sqlalchemy.pool, config['acrmultisite.poolclass'])
             self.engines[used_db] = engine_from_config(config, 'sqlalchemy.')
 
         return getattr(self.engines[used_db], name)
