@@ -135,12 +135,6 @@ feel free to use it for any project and for more informations refer to <a href="
     ci = model.Slice(view='html', content=c, page=default_page, zone='rightbar', name="sidebar")
     model.DBSession.add(ci)
 
-    model.DBSession.flush()
-    transaction.commit()
-
-    PluginsManager.setup_models(model.DBSession, model.DeclarativeBase,
-                                model.User, model.Group)
-
     model.DBSession.flush()
     transaction.commit()
     print "Successfully setup"
